@@ -919,7 +919,7 @@ void write_disk_stat_header(int *fctr)
 		else {
 			printf("   rsec/s   wsec/s");
 		}
-		printf(" avgrq-sz avgqu-sz   await  svctm  %%util\n");
+		printf(" avgrq-sz avgqu-sz   await r_await w_await  svctm  %%util\n");
 	}
 	else {
 		/* Basic stats */
@@ -986,6 +986,7 @@ void write_ext_stat(int curr, unsigned long long itv, int fctr,
 {
 	struct stats_disk sdc, sdp;
 	struct ext_disk_stats xds;
+	double r_await, w_await;
 	
 	/*
 	 * Counters overflows are possible, but don't need to be handled in
@@ -1014,8 +1015,15 @@ void write_ext_stat(int curr, unsigned long long itv, int fctr,
 	
 	compute_ext_disk_stats(&sdc, &sdp, itv, &xds);
 	
-	/*      DEV   rrq/s wrq/s   r/s   w/s  rsec  wsec  rqsz  qusz await svctm %util */
-	printf("%-13s %8.2f %8.2f %7.2f %7.2f %8.2f %8.2f %8.2f %8.2f %7.2f %6.2f %6.2f\n",
+	r_await = (ioi->rd_ios - ioj->rd_ios) ?
+		  (ioi->rd_ticks - ioj->rd_ticks) /
+		  ((double) (ioi->rd_ios - ioj->rd_ios)) : 0.0;
+	w_await = (ioi->wr_ios - ioj->wr_ios) ?
+		  (ioi->wr_ticks - ioj->wr_ticks) /
+		  ((double) (ioi->wr_ios - ioj->wr_ios)) : 0.0;
+
+	/*      DEV   rrq/s wrq/s   r/s   w/s  rsec  wsec  rqsz  qusz await r_await w_await svctm %util */
+	printf("%-13s %8.2f %8.2f %7.2f %7.2f %8.2f %8.2f %8.2f %8.2f %7.2f %7.2f %7.2f %6.2f %6.2f\n",
 	       shi->name,
 	       S_VALUE(ioj->rd_merges, ioi->rd_merges, itv),
 	       S_VALUE(ioj->wr_merges, ioi->wr_merges, itv),
@@ -1026,6 +1034,8 @@ void write_ext_stat(int curr, unsigned long long itv, int fctr,
 	       xds.arqsz,
 	       S_VALUE(ioj->rq_ticks, ioi->rq_ticks, itv) / 1000.0,
 	       xds.await,
+	       r_await,
+	       w_await,
 	       /* The ticks output is biased to output 1000 ticks per second */
 	       xds.svctm,
 	       /* Again: Ticks in milliseconds */
