@@ -1,6 +1,6 @@
 /*
  * rd_stats.h: Include file used to read system statistics
- * (C) 1999-2008 by Sebastien Godard (sysstat <at> orange.fr)
+ * (C) 1999-2009 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _RD_STATS_H
@@ -29,6 +29,7 @@
 #define CNT_ALL_DEV	0
 #define CNT_USED_DEV	1
 
+#define READ_PROC_STAT		0
 #define READ_DISKSTATS		1
 #define READ_PPARTITIONS	2
 
@@ -47,11 +48,14 @@
 #define PTY_NR		"/proc/sys/kernel/pty/nr"
 #define NET_DEV		"/proc/net/dev"
 #define NET_SOCKSTAT	"/proc/net/sockstat"
+#define NET_SOCKSTAT6	"/proc/net/sockstat6"
 #define NET_RPC_NFS	"/proc/net/rpc/nfs"
 #define NET_RPC_NFSD	"/proc/net/rpc/nfsd"
 #define LOADAVG		"/proc/loadavg"
 #define VMSTAT		"/proc/vmstat"
 #define NET_SNMP	"/proc/net/snmp"
+#define NET_SNMP6	"/proc/net/snmp6"
+#define CPUINFO		"/proc/cpuinfo"
 
 
 /*
@@ -264,7 +268,7 @@ struct stats_net_nfsd {
 
 #define STATS_NET_NFSD_SIZE	(sizeof(struct stats_net_nfsd))
 
-/* Structure for network sockets statistics */
+/* Structure for IPv4 sockets statistics */
 struct stats_net_sock {
 	unsigned int  sock_inuse	__attribute__ ((aligned (4)));
 	unsigned int  tcp_inuse		__attribute__ ((packed));
@@ -373,6 +377,110 @@ struct stats_net_udp {
 
 #define STATS_NET_UDP_SIZE	(sizeof(struct stats_net_udp))
 
+/* Structure for IPv6 statistics */
+struct stats_net_ip6 {
+	unsigned long InReceives6	__attribute__ ((aligned (8)));
+	unsigned long OutForwDatagrams6	__attribute__ ((aligned (8)));
+	unsigned long InDelivers6	__attribute__ ((aligned (8)));
+	unsigned long OutRequests6	__attribute__ ((aligned (8)));
+	unsigned long ReasmReqds6	__attribute__ ((aligned (8)));
+	unsigned long ReasmOKs6		__attribute__ ((aligned (8)));
+	unsigned long InMcastPkts6	__attribute__ ((aligned (8)));
+	unsigned long OutMcastPkts6	__attribute__ ((aligned (8)));
+	unsigned long FragOKs6		__attribute__ ((aligned (8)));
+	unsigned long FragCreates6	__attribute__ ((aligned (8)));
+};
+
+#define STATS_NET_IP6_SIZE	(sizeof(struct stats_net_ip6))
+
+/* Structure for IPv6 errors statistics */
+struct stats_net_eip6 {
+	unsigned long InHdrErrors6	__attribute__ ((aligned (8)));
+	unsigned long InAddrErrors6	__attribute__ ((aligned (8)));
+	unsigned long InUnknownProtos6	__attribute__ ((aligned (8)));
+	unsigned long InTooBigErrors6	__attribute__ ((aligned (8)));
+	unsigned long InDiscards6	__attribute__ ((aligned (8)));
+	unsigned long OutDiscards6	__attribute__ ((aligned (8)));
+	unsigned long InNoRoutes6	__attribute__ ((aligned (8)));
+	unsigned long OutNoRoutes6	__attribute__ ((aligned (8)));
+	unsigned long ReasmFails6	__attribute__ ((aligned (8)));
+	unsigned long FragFails6	__attribute__ ((aligned (8)));
+	unsigned long InTruncatedPkts6	__attribute__ ((aligned (8)));
+};
+
+#define STATS_NET_EIP6_SIZE	(sizeof(struct stats_net_eip6))
+
+/* Structure for ICMPv6 statistics */
+struct stats_net_icmp6 {
+	unsigned long InMsgs6				__attribute__ ((aligned (8)));
+	unsigned long OutMsgs6				__attribute__ ((aligned (8)));
+	unsigned long InEchos6				__attribute__ ((aligned (8)));
+	unsigned long InEchoReplies6			__attribute__ ((aligned (8)));
+	unsigned long OutEchoReplies6			__attribute__ ((aligned (8)));
+	unsigned long InGroupMembQueries6		__attribute__ ((aligned (8)));
+	unsigned long InGroupMembResponses6		__attribute__ ((aligned (8)));
+	unsigned long OutGroupMembResponses6		__attribute__ ((aligned (8)));
+	unsigned long InGroupMembReductions6		__attribute__ ((aligned (8)));
+	unsigned long OutGroupMembReductions6		__attribute__ ((aligned (8)));
+	unsigned long InRouterSolicits6			__attribute__ ((aligned (8)));
+	unsigned long OutRouterSolicits6		__attribute__ ((aligned (8)));
+	unsigned long InRouterAdvertisements6		__attribute__ ((aligned (8)));
+	unsigned long InNeighborSolicits6		__attribute__ ((aligned (8)));
+	unsigned long OutNeighborSolicits6		__attribute__ ((aligned (8)));
+	unsigned long InNeighborAdvertisements6		__attribute__ ((aligned (8)));
+	unsigned long OutNeighborAdvertisements6	__attribute__ ((aligned (8)));
+};
+
+#define STATS_NET_ICMP6_SIZE	(sizeof(struct stats_net_icmp6))
+
+/* Structure for ICMPv6 error message statistics */
+struct stats_net_eicmp6 {
+	unsigned long InErrors6		__attribute__ ((aligned (8)));
+	unsigned long InDestUnreachs6	__attribute__ ((aligned (8)));
+	unsigned long OutDestUnreachs6	__attribute__ ((aligned (8)));
+	unsigned long InTimeExcds6	__attribute__ ((aligned (8)));
+	unsigned long OutTimeExcds6	__attribute__ ((aligned (8)));
+	unsigned long InParmProblems6	__attribute__ ((aligned (8)));
+	unsigned long OutParmProblems6	__attribute__ ((aligned (8)));
+	unsigned long InRedirects6	__attribute__ ((aligned (8)));
+	unsigned long OutRedirects6	__attribute__ ((aligned (8)));
+	unsigned long InPktTooBigs6	__attribute__ ((aligned (8)));
+	unsigned long OutPktTooBigs6	__attribute__ ((aligned (8)));
+};
+
+#define STATS_NET_EICMP6_SIZE	(sizeof(struct stats_net_eicmp6))
+
+/* Structure for UDPv6 statistics */
+struct stats_net_udp6 {
+	unsigned long InDatagrams6	__attribute__ ((aligned (8)));
+	unsigned long OutDatagrams6	__attribute__ ((aligned (8)));
+	unsigned long NoPorts6		__attribute__ ((aligned (8)));
+	unsigned long InErrors6		__attribute__ ((aligned (8)));
+};
+
+#define STATS_NET_UDP6_SIZE	(sizeof(struct stats_net_udp6))
+
+/* Structure for IPv6 sockets statistics */
+struct stats_net_sock6 {
+	unsigned int  tcp6_inuse	__attribute__ ((aligned (4)));
+	unsigned int  udp6_inuse	__attribute__ ((packed));
+	unsigned int  raw6_inuse	__attribute__ ((packed));
+	unsigned int  frag6_inuse	__attribute__ ((packed));
+};
+
+#define STATS_NET_SOCK6_SIZE	(sizeof(struct stats_net_sock6))
+
+/*
+ * Structure for CPU frequency statistics.
+ * In activity buffer: First structure is for global CPU utilisation ("all").
+ * Following structures are for each individual CPU (0, 1, etc.)
+ */
+struct stats_pwr_cpufreq {
+	unsigned long cpufreq	__attribute__ ((aligned (8)));
+};
+
+#define STATS_PWR_CPUFREQ_SIZE	(sizeof(struct stats_pwr_cpufreq))
+
 /*
  ***************************************************************************
  * Prototypes for functions used to read system statistics
@@ -390,26 +498,14 @@ extern void
 	read_loadavg(struct stats_queue *);
 extern void
 	read_meminfo(struct stats_memory *);
-extern unsigned int
+extern void
 	read_vmstat_swap(struct stats_swap *);
 extern void
-	read_stat_swap(struct stats_swap *);
-extern int
 	read_vmstat_paging(struct stats_paging *);
-extern void
-	read_stat_paging(struct stats_paging *);
 extern void
 	read_diskstats_io(struct stats_io *);
 extern void
-	read_ppartitions_io(struct stats_io *);
-extern void
-	read_stat_io(struct stats_io *);
-extern void
-	read_diskstats_disk(struct stats_disk *, int);
-extern void
-	read_partitions_disk(struct stats_disk *, int);
-extern void
-	read_stat_disk(struct stats_disk *, int);
+	read_diskstats_disk(struct stats_disk *, int, int);
 extern void
 	read_tty_driver_serial(struct stats_serial *, int);
 extern void
@@ -440,6 +536,20 @@ extern void
 	read_net_udp(struct stats_net_udp *);
 extern void
 	read_uptime(unsigned long long *);
+extern void
+	read_net_sock6(struct stats_net_sock6 *);
+extern void
+	read_net_ip6(struct stats_net_ip6 *);
+extern void
+	read_net_eip6(struct stats_net_eip6 *);
+extern void
+	read_net_icmp6(struct stats_net_icmp6 *);
+extern void
+	read_net_eicmp6(struct stats_net_eicmp6 *);
+extern void
+	read_net_udp6(struct stats_net_udp6 *);
+extern void
+	read_cpuinfo(struct stats_pwr_cpufreq *, int);
 
 /*
  ***************************************************************************
@@ -456,15 +566,11 @@ extern int
 extern int
 	get_diskstats_dev_nr(int, int);
 extern int
-	get_ppartitions_dev_nr(int);
-extern unsigned int
-	get_disk_io_nr(void);
-extern int
-	get_disk_nr(unsigned int *);
+	get_disk_nr(unsigned int);
 extern int
 	get_cpu_nr(unsigned int);
 extern int
-	get_irqcpu_nr(int, int);
+	get_irqcpu_nr(char *, int, int);
 
 
 #endif /* _RD_STATS_H */
